/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.camera.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.camera.domain.DmCamera;
import me.zhengjie.modules.dm.camera.service.DmCameraService;
import me.zhengjie.modules.dm.camera.service.dto.DmCameraQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import java.util.Map;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author xwx
* @date 2021-04-20
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "camera管理")
@RequestMapping("/api/dmCamera")
public class DmCameraController {

    private final DmCameraService dmCameraService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmCamera:list')")
    public void download(HttpServletResponse response, DmCameraQueryCriteria criteria) throws IOException {
        dmCameraService.download(dmCameraService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询camera")
    @ApiOperation("查询camera")
    @PreAuthorize("@el.check('dmCamera:list')")
    public ResponseEntity<Object> query(DmCameraQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmCameraService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增camera")
    @ApiOperation("新增camera")
    @PreAuthorize("@el.check('dmCamera:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmCamera resources){
        return new ResponseEntity<>(dmCameraService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改camera")
    @ApiOperation("修改camera")
    @PreAuthorize("@el.check('dmCamera:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmCamera resources){
        dmCameraService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除camera")
    @ApiOperation("删除camera")
    @PreAuthorize("@el.check('dmCamera:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmCameraService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }

    @PutMapping(value = "/checkCode")
    @Log("判断dmCamera是否存在相同Code")
    @ApiOperation("判断dmCamera是否存在相同Code")
    public ResponseEntity<Object> checkCode(@RequestBody Map<String,String> params) {
        int count  = dmCameraService.checkCode(params.get("code"),params.get("id")==null?null:Long.parseLong(params.get("id")));
        return new ResponseEntity<>(count > 0,HttpStatus.OK);
    }
}