/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.device.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.device.domain.DmDevice;
import me.zhengjie.modules.dm.device.service.DmDeviceService;
import me.zhengjie.modules.dm.device.service.dto.DmDeviceQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import java.util.Map;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author xwx
* @date 2021-04-20
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "dmDevice管理")
@RequestMapping("/api/dmDevice")
public class DmDeviceController {

    private final DmDeviceService dmDeviceService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmDevice:list')")
    public void download(HttpServletResponse response, DmDeviceQueryCriteria criteria) throws IOException {
        dmDeviceService.download(dmDeviceService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询dmDevice")
    @ApiOperation("查询dmDevice")
    @PreAuthorize("@el.check('dmDevice:list')")
    public ResponseEntity<Object> query(DmDeviceQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmDeviceService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增dmDevice")
    @ApiOperation("新增dmDevice")
    @PreAuthorize("@el.check('dmDevice:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmDevice resources){
        return new ResponseEntity<>(dmDeviceService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改dmDevice")
    @ApiOperation("修改dmDevice")
    @PreAuthorize("@el.check('dmDevice:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmDevice resources){
        dmDeviceService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除dmDevice")
    @ApiOperation("删除dmDevice")
    @PreAuthorize("@el.check('dmDevice:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmDeviceService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }

    @PutMapping(value = "/checkCode")
    @Log("判断dmDevice是否存在相同Code")
    @ApiOperation("判断dmDevice是否存在相同Code")
    public ResponseEntity<Object> checkCode(@RequestBody Map<String,String> params) {
        int count  = dmDeviceService.checkCode(params.get("code"),params.get("id")==null?null:Long.parseLong(params.get("id")));
        return new ResponseEntity<>(count > 0,HttpStatus.OK);
    }


}