/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.foodPj.service;

import me.zhengjie.modules.dm.foodPj.domain.DmFoodPj;
import me.zhengjie.modules.dm.foodPj.service.dto.DmFoodPjDto;
import me.zhengjie.modules.dm.foodPj.service.dto.DmFoodPjQueryCriteria;
import org.springframework.data.domain.Pageable;
import java.util.Map;
import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @description 服务接口
* @author sunmz
* @date 2021-09-15
**/
public interface DmFoodPjService {

    /**
    * 查询数据分页
    * @param criteria 条件
    * @param pageable 分页参数
    * @return Map<String,Object>
    */
    Map<String,Object> queryAll(DmFoodPjQueryCriteria criteria, Pageable pageable);

    /**
    * 查询所有数据不分页
    * @param criteria 条件参数
    * @return List<DmFoodPjDto>
    */
    List<DmFoodPjDto> queryAll(DmFoodPjQueryCriteria criteria);

    /**
     * 根据ID查询
     * @param id ID
     * @return DmFoodPjDto
     */
    DmFoodPjDto findById(Long id);

    /**
    * 创建
    * @param resources /
    * @return DmFoodPjDto
    */
    DmFoodPjDto create(DmFoodPj resources);

    /**
     * 创建
     * @param resources /
     * @return DmFoodPjDto
     */
    DmFoodPjDto createApp(DmFoodPj resources);

    /**
    * 编辑
    * @param resources /
    */
    void update(DmFoodPj resources);

    /**
    * 多选删除
    * @param ids /
    */
    void deleteAll(Long[] ids);

    /**
    * 导出数据
    * @param all 待导出的数据
    * @param response /
    * @throws IOException /
    */
    void download(List<DmFoodPjDto> all, HttpServletResponse response) throws IOException;

    /**
     * 根据菜品id查询评价详情
     * @param code
     * @return
     */
    List<Map<String,Object>> findByFoodCode(String code);
}