/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.information.domain;

import lombok.Data;
import cn.hutool.core.bean.BeanUtil;
import io.swagger.annotations.ApiModelProperty;
import cn.hutool.core.bean.copier.CopyOptions;
import javax.persistence.*;
import javax.persistence.CascadeType;
import javax.validation.constraints.*;
import javax.persistence.Entity;
import javax.persistence.Table;

import me.zhengjie.base.BaseEntity;
import me.zhengjie.modules.dm.user.domain.DmUser;
import org.hibernate.annotations.*;
import java.sql.Timestamp;
import java.io.Serializable;
import java.util.List;

/**
* @website https://el-admin.vip
* @description /
* @author xwx
* @date 2022-06-06
**/
@Entity
@Data
@Table(name="dm_information")
public class DmInformation extends BaseEntity implements Serializable {

    @Id
    @Column(name = "id")
    @ApiModelProperty(value = "主键")
    private Long id;

    @Column(name = "content",nullable = false)
    @NotBlank
    @ApiModelProperty(value = "发布内容(需发布的信息内容)")
    private String content;

    @Column(name = "status")
    @ApiModelProperty(value = "(00-待审核  01-审批通过(已发布） 02-审核未通过)")
    private String status;

    @ApiModelProperty(value = "审批人")
    @Column(name = "approval_user")
//    @OneToOne
//    @NotFound(action = NotFoundAction.IGNORE)
//    @JoinColumn(name = "approval_user",referencedColumnName = "id")
    private String approvalUser;

    @Column(name = "task_id")
    @ApiModelProperty(value = "任务ID act_ru_task")
    private String taskId;

    @Column(name = "proc_inst_id")
    @ApiModelProperty(value = "任务实例id act_ru_execution")
    private String procInstId;

    @ApiModelProperty(value = "发起人")
//    @OneToOne
//    @NotFound(action = NotFoundAction.IGNORE)
//    @JoinColumn(name = "request_user",referencedColumnName = "id")
    @Column(name = "request_user")
    private String requestUser;

    @Column(name = "release_time")
    @ApiModelProperty(value = "发布时间")
    private Timestamp releaseTime;

    @Column(name = "approval_time")
    @ApiModelProperty(value = "审批时间")
    private Timestamp approvalTime;

    @Column(name = "title")
    @ApiModelProperty(value = "发布标题")
    @NotBlank
    private String title;

    @Column(name = "approval_remark")
    @ApiModelProperty(value = "审批备注")
    private String approvalRemark;

    @Column(name = "is_has_approval")
    @ApiModelProperty(value = "是否设置审批人 1-true 0-false")
    private String isHasApproval;

    @Column(name = "is_valid")
    @ApiModelProperty(value = "是否有效")
    private String isValid;

    @Transient
    private List<DmUser> approvalUserList;

    public void copy(DmInformation source){
        BeanUtil.copyProperties(source,this, CopyOptions.create().setIgnoreNullValue(true));
    }
}