/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.order.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.order.domain.DmOrderRecord;
import me.zhengjie.modules.dm.order.service.DmOrderRecordService;
import me.zhengjie.modules.dm.order.service.dto.DmOrderRecordQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author sunmz
* @date 2021-09-15
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "order管理")
@RequestMapping("/api/dmOrderRecord")
public class DmOrderRecordController {

    private final DmOrderRecordService dmOrderRecordService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmOrderRecord:list')")
    public void download(HttpServletResponse response, DmOrderRecordQueryCriteria criteria) throws IOException {
        dmOrderRecordService.download(dmOrderRecordService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询order")
    @ApiOperation("查询order")
    @PreAuthorize("@el.check('dmOrderRecord:list')")
    public ResponseEntity<Object> query(DmOrderRecordQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmOrderRecordService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @GetMapping(value = "/queryDetails")
    @Log("查询order")
    @ApiOperation("查询order")
    public ResponseEntity<Object> queryDetails(DmOrderRecordQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmOrderRecordService.queryDetails(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增order")
    @ApiOperation("新增order")
    @PreAuthorize("@el.check('dmOrderRecord:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmOrderRecord resources){
        return new ResponseEntity<>(dmOrderRecordService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改order")
    @ApiOperation("修改order")
    @PreAuthorize("@el.check('dmOrderRecord:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmOrderRecord resources){
        dmOrderRecordService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除order")
    @ApiOperation("删除order")
    @PreAuthorize("@el.check('dmOrderRecord:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmOrderRecordService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }

    @GetMapping(value = "/panelGroup")
    @Log("首页统计信息")
    @ApiOperation("首页统计信息")
    public ResponseEntity<Object> panelGroup(){
        return new ResponseEntity<>(dmOrderRecordService.panelGroup(),HttpStatus.OK);
    }
}