/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.order.service;

import me.zhengjie.modules.dm.order.domain.DmOrderItem;
import me.zhengjie.modules.dm.order.domain.DmOrderRecord;
import me.zhengjie.modules.dm.order.service.dto.DmExpenseCalendar;
import me.zhengjie.modules.dm.order.service.dto.DmOrderRecordDto;
import me.zhengjie.modules.dm.order.service.dto.DmOrderRecordQueryCriteria;
import org.springframework.data.domain.Pageable;
import java.util.Map;
import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @description 服务接口
* @author sunmz
* @date 2021-09-15
**/
public interface DmOrderRecordService {

    /**
    * 查询数据分页
    * @param criteria 条件
    * @param pageable 分页参数
    * @return Map<String,Object>
    */
    Map<String,Object> queryAll(DmOrderRecordQueryCriteria criteria, Pageable pageable);

    /**
     * 查询数据分页
     * @param criteria 条件
     * @param pageable 分页参数
     * @return Map<String,Object>
     */
    Map<String,Object> queryDetails(DmOrderRecordQueryCriteria criteria, Pageable pageable);

    /**
    * 查询所有数据不分页
    * @param criteria 条件参数
    * @return List<DmOrderRecordDto>
    */
    List<DmOrderRecordDto> queryAll(DmOrderRecordQueryCriteria criteria);

    /**
     * 根据ID查询
     * @param id ID
     * @return DmOrderRecordDto
     */
    DmOrderRecordDto findById(Long id);

    /**
    * 创建
    * @param resources /
    * @return DmOrderRecordDto
    */
    DmOrderRecordDto create(DmOrderRecord resources);

    /**
    * 编辑
    * @param resources /
    */
    void update(DmOrderRecord resources);

    /**
    * 多选删除
    * @param ids /
    */
    void deleteAll(Long[] ids);

    /**
    * 导出数据
    * @param all 待导出的数据
    * @param response /
    * @throws IOException /
    */
    void download(List<DmOrderRecordDto> all, HttpServletResponse response) throws IOException;

    /**
     * 首页统计信息
     */
    Map<String,Object> panelGroup();

    List<Map<String,Object>> selectOrderRecord();

    /**
     * 创建
     * @param resources /
     * @return DmOrderRecordDto
     */
    void createOrderRecord(DmExpenseCalendar resources);
    void createOrderItem(DmExpenseCalendar resources);

    Integer countOrderAmt();
}