/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.rfidTableware.domain;

import lombok.Data;
import cn.hutool.core.bean.BeanUtil;
import io.swagger.annotations.ApiModelProperty;
import cn.hutool.core.bean.copier.CopyOptions;
import me.zhengjie.utils.SecurityUtils;
import org.springframework.security.core.userdetails.UserDetails;

import javax.persistence.*;
import javax.validation.constraints.*;
import java.sql.Timestamp;
import java.io.Serializable;
import java.util.Date;

/**
* @website https://el-admin.vip
* @description /
* @author sunmz
* @date 2021-09-15
**/
@Entity
@Data
@Table(name="dm_rfid_tableware")
public class DmRfidTableware implements Serializable {

    @Id
    @Column(name = "id")
    @ApiModelProperty(value = "id")
    private Long id;

    @Column(name = "code",nullable = false)
    @NotBlank
    @ApiModelProperty(value = "芯片编号(餐具内RFID编号)")
    private String code;

    @Column(name = "name",nullable = false)
    @NotBlank
    @ApiModelProperty(value = "餐具名称(餐具名称)")
    private String name;

    @Column(name = "restaurant",nullable = false)
    @NotBlank
    @ApiModelProperty(value = "所属餐厅(餐具所属餐厅)")
    private String restaurant;

    @Column(name = "create_by")
    @ApiModelProperty(value = "创建者")
    private String createBy;

    @Column(name = "update_by")
    @ApiModelProperty(value = "更新者")
    private String updateBy;

    @Column(name = "create_time")
    @ApiModelProperty(value = "创建日期")
    private Timestamp createTime;

    @Column(name = "update_time")
    @ApiModelProperty(value = "更新时间")
    private Timestamp updateTime;

    @Column(name = "user_time")
    @ApiModelProperty(value = "使用日期")
    private Timestamp userTime;

    public void copy(DmRfidTableware source){
        BeanUtil.copyProperties(source,this, CopyOptions.create().setIgnoreNullValue(true));
    }

    @PrePersist
    public void prePersist() {
        UserDetails user = SecurityUtils.getCurrentUser();
        this.createBy = user.getUsername();
        this.createTime = new Timestamp(new Date().getTime());
    }

    @PreUpdate
    public void preUPdate() {
        UserDetails user = SecurityUtils.getCurrentUser();
        this.updateBy = user.getUsername();
        this.updateTime = new Timestamp(new Date().getTime());
    }
}