/*
*  Copyright 2019-2020 Zheng Jie
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*  http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
*/
package me.zhengjie.modules.dm.settlement.rest;

import me.zhengjie.annotation.Log;
import me.zhengjie.modules.dm.settlement.domain.DmSettlement;
import me.zhengjie.modules.dm.settlement.service.DmSettlementService;
import me.zhengjie.modules.dm.settlement.service.dto.DmSettlementQueryCriteria;
import org.springframework.data.domain.Pageable;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

/**
* @website https://el-admin.vip
* @author xwx
* @date 2021-04-22
**/
@RestController
@RequiredArgsConstructor
@Api(tags = "settlement管理")
@RequestMapping("/api/dmSettlement")
public class DmSettlementController {

    private final DmSettlementService dmSettlementService;

    @Log("导出数据")
    @ApiOperation("导出数据")
    @GetMapping(value = "/download")
    @PreAuthorize("@el.check('dmSettlement:list')")
    public void download(HttpServletResponse response, DmSettlementQueryCriteria criteria) throws IOException {
        dmSettlementService.download(dmSettlementService.queryAll(criteria), response);
    }

    @GetMapping
    @Log("查询settlement")
    @ApiOperation("查询settlement")
    @PreAuthorize("@el.check('dmSettlement:list')")
    public ResponseEntity<Object> query(DmSettlementQueryCriteria criteria, Pageable pageable){
        return new ResponseEntity<>(dmSettlementService.queryAll(criteria,pageable),HttpStatus.OK);
    }

    @PostMapping
    @Log("新增settlement")
    @ApiOperation("新增settlement")
    @PreAuthorize("@el.check('dmSettlement:add')")
    public ResponseEntity<Object> create(@Validated @RequestBody DmSettlement resources){
        return new ResponseEntity<>(dmSettlementService.create(resources),HttpStatus.CREATED);
    }

    @PutMapping
    @Log("修改settlement")
    @ApiOperation("修改settlement")
    @PreAuthorize("@el.check('dmSettlement:edit')")
    public ResponseEntity<Object> update(@Validated @RequestBody DmSettlement resources){
        dmSettlementService.update(resources);
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }

    @Log("删除settlement")
    @ApiOperation("删除settlement")
    @PreAuthorize("@el.check('dmSettlement:del')")
    @DeleteMapping
    public ResponseEntity<Object> delete(@RequestBody Long[] ids) {
        dmSettlementService.deleteAll(ids);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}