/**
 * Copyright (C), 2022-08-02
 * FileName: DiningStatements
 * Author:   wanglongda
 * Date:     2022/8/2 15:10
 * Description: 用餐报表
 */
package me.zhengjie.modules.quartz.task;/**
 * Created Name: wanglongda
 * Created Time: 2022/8/2 15:10
 * Description: iot-zhcy
 */

import cn.hutool.core.util.ObjectUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import me.zhengjie.modules.dm.statement.repository.DmHaveDinnerRepository;
import me.zhengjie.modules.dm.statement.service.mapstruct.DmHaveDinnerMapper;
import me.zhengjie.utils.StringUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Component;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.List;
import java.util.Map;

/**
 * <功能简要> <br>
 * <用餐报表>
 *
 * @Author wanglongda
 * @createTime 2022/8/2 15:10
 * @Version 1.0.0
 */

@Slf4j
@Component
@RequiredArgsConstructor
public class DiningStatementsTask {

    private final DmHaveDinnerRepository dmHaveDinnerRepository;

    public void  run(){
        //日报
        dayDiningStatements();
        //周报
        weekDiningStatements();
        //月报
        monthDiningStatements();
        //年报
        yearDiningStatements();
    }

    /**
     * 定时生成用餐日报  DAY_DINING_STATEMENTS
     */
    public void dayDiningStatements(){
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");

        Calendar instance = Calendar.getInstance();
        //当前时间
        String nowTime = simpleDateFormat.format(instance.getTime()) + " 23:59:59";
        String StartTime = simpleDateFormat.format(instance.getTime()) + " 00:00:00";

        /**
         * 前三名
         */
        //第一步判断是否有DAY_DINING_STATEMENTS_TOP视图
        String viewTopName = dmHaveDinnerRepository.judgeView("DAY_DINING_STATEMENTS_TOP");
//由于是一天一生成 那就再新增之前就要删除之前的视图
        if (!StringUtils.isEmpty(viewTopName)){
            //删除视图
            dmHaveDinnerRepository.dropDayTopView("DAY_DINING_STATEMENTS_TOP");
            //创建视图
            dmHaveDinnerRepository.createDayDiningStatementsTopThreeView(StartTime,nowTime,"DAY_DINING_STATEMENTS_TOP");
        }else {
            //创建视图
            dmHaveDinnerRepository.createDayDiningStatementsTopThreeView(StartTime,nowTime,"DAY_DINING_STATEMENTS_TOP");
        }
        /**
         * 后三名
         */
        //第一步判断是否有DAY_DINING_STATEMENTS_STOP视图
       String viewStopName = dmHaveDinnerRepository.judgeView("DAY_DINING_STATEMENTS_STOP");
       //由于是一天一生成 那就再新增之前就要删除之前的视图
       if (!StringUtils.isEmpty(viewStopName)){
           //删除视图
           dmHaveDinnerRepository.dropDayStopView("DAY_DINING_STATEMENTS_STOP");
           //创建视图
           dmHaveDinnerRepository.createDayDiningStatementsStopThreeView(StartTime,nowTime,"DAY_DINING_STATEMENTS_STOP");
       }else {
           //创建视图
           dmHaveDinnerRepository.createDayDiningStatementsStopThreeView(StartTime,nowTime,"DAY_DINING_STATEMENTS_STOP");
       }

    }

    /**
     * 定时生成用餐周报  WEEK_DINING_STATEMENTS
     */
    public void weekDiningStatements(){
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");

        Calendar instance = Calendar.getInstance();
        // 当前当前时间在当年中是第几个星期  后面要用来判断是否执行
        int weeksInWeekYear = instance.get(Calendar.WEEK_OF_YEAR);
        //判断当前时间在当前星期中事星期几  由于日历类中星期一是从周日算的
        int i = instance.get(Calendar.DAY_OF_WEEK)-1;

        //当前时间
        String nowTime = "";
        //开始时间
        String startTime = "";

        if (i==0){
            instance.add(Calendar.DATE, 1-i);
            startTime = simpleDateFormat.format(instance.getTime()) + " 00:00:00";
            instance.add(Calendar.DATE, 7-1);
            nowTime = simpleDateFormat.format(instance.getTime()) + " 23:59:59";
        }else {
            instance.add(Calendar.DATE,1-i);
            startTime = simpleDateFormat.format(instance.getTime()) + " 00:00:00";
            instance.add(Calendar.DATE, 7-1);
            nowTime = simpleDateFormat.format(instance.getTime()) + " 23:59:59";
        }
        /**
         * 前三名
         */
        //第一步判断是否有WEEK_DINING_STATEMENTS视图
        String viewTopName = dmHaveDinnerRepository.judgeView("WEEK_DINING_STATEMENTS_TOP");
        if (!StringUtils.isEmpty(viewTopName)){
            //查询视图
            Page<List<Map<String, Object>>> maps = dmHaveDinnerRepository.selectWeekTopView(startTime, nowTime, null);
            if (ObjectUtil.isEmpty(maps)){
                //删除视图
                dmHaveDinnerRepository.dropWeekTopView("WEEK_DINING_STATEMENTS_TOP");
                //创建视图
                dmHaveDinnerRepository.createWeekDiningStatementsTopThreeView(startTime,nowTime,"WEEK_DINING_STATEMENTS_TOP");
            }
        }else{
            //创建视图
            dmHaveDinnerRepository.createWeekDiningStatementsTopThreeView(startTime,nowTime,"WEEK_DINING_STATEMENTS_TOP");
        }

        /**
         * 后三名
         */
        //第一步判断是否有WEEK_DINING_STATEMENTS视图
        String viewStopName = dmHaveDinnerRepository.judgeView("WEEK_DINING_STATEMENTS_STOP");
        //由于是一周一生成 那就再新增之前就要删除之前的视图
        if (!StringUtils.isEmpty(viewStopName)){
            //查询视图
            Page<List<Map<String, Object>>> maps = dmHaveDinnerRepository.selectWeekStopView(startTime, nowTime, null);
             if (ObjectUtil.isEmpty(maps)){
                 //删除视图
                 dmHaveDinnerRepository.dropWeekTopView("WEEK_DINING_STATEMENTS_STOP");
                 //创建视图
                 dmHaveDinnerRepository.createWeekDiningStatementsStopThreeView(startTime,nowTime,"WEEK_DINING_STATEMENTS_STOP");
             }
        }else {
            //创建视图
            dmHaveDinnerRepository.createWeekDiningStatementsStopThreeView(startTime,nowTime,"WEEK_DINING_STATEMENTS_STOP");
        }

    }


    /**
     * 定时生成用餐月报  MONTH_DINING_STATEMENTS
     */
    public void  monthDiningStatements(){
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM");
        Calendar instance = Calendar.getInstance();
        // 当前月份
        int monthsInYear = instance.get(Calendar.MONTH)+1;
        // 当前月份最大多少天
        int actualMaximum = instance.getActualMaximum(Calendar.DATE);
        //当前时间
        String nowTime = simpleDateFormat.format(instance.getTime()) + "-"+actualMaximum+" 23:59:59";
        String startTime = simpleDateFormat.format(instance.getTime()) + "-01 00:00:00";
        /**
         * 前三名
         */
        //第一步判断是否有WEEK_DINING_STATEMENTS视图
        String viewTopName = dmHaveDinnerRepository.judgeView("MONTH_DINING_STATEMENTS_TOP");
        if (!StringUtils.isEmpty(viewTopName)){
            //查询视图
            Page<List<Map<String, Object>>> maps = dmHaveDinnerRepository.selectMonthTopView(startTime, nowTime, null);
            if (ObjectUtil.isEmpty(maps)){
                //删除视图
                dmHaveDinnerRepository.dropWeekTopView("MONTH_DINING_STATEMENTS_TOP");
                //创建视图
                dmHaveDinnerRepository.createWeekDiningStatementsTopThreeView(startTime,nowTime,"MONTH_DINING_STATEMENTS_TOP");
            }
        }else{
            //创建视图
            dmHaveDinnerRepository.createMonthDiningStatementsTopThreeView(startTime,nowTime,"MONTH_DINING_STATEMENTS_TOP");
        }

        /**
         * 后三名
         */
        //第一步判断是否有WEEK_DINING_STATEMENTS视图
        String viewStopName = dmHaveDinnerRepository.judgeView("MONTH_DINING_STATEMENTS_STOP");
        //由于是一周一生成 那就再新增之前就要删除之前的视图
        if (!StringUtils.isEmpty(viewStopName)){
            //查询视图
            Page<List<Map<String, Object>>> maps = dmHaveDinnerRepository.selectWeekStopView(startTime, nowTime, null);
            if (ObjectUtil.isEmpty(maps)){
                //删除视图
                dmHaveDinnerRepository.dropMonthTopView("MONTH_DINING_STATEMENTS_STOP");
                //创建视图
                dmHaveDinnerRepository.createMonthDiningStatementsStopThreeView(startTime,nowTime,"MONTH_DINING_STATEMENTS_STOP");
            }
        }else {
            //创建视图
            dmHaveDinnerRepository.createMonthDiningStatementsStopThreeView(startTime,nowTime,"MONTH_DINING_STATEMENTS_STOP");
        }

    }

    /**
     * 定时生成用餐年报  MONTH_DINING_STATEMENTS
     */
    public void  yearDiningStatements(){
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy");
        Calendar instance = Calendar.getInstance();
        //设置到12月用来取最大天数
        instance.set(Calendar.MONTH, 11);
        // 当年最大月份最大多少天
        int actualMaximum = instance.getActualMaximum(Calendar.DATE);
        //当前时间
        String nowTime = simpleDateFormat.format(instance.getTime())+ "-12-"+actualMaximum+" 23:59:59";
        String startTime = simpleDateFormat.format( instance.getTime())+ "-01-01 00:00:00";
        /**
         * 前三名
         */
        //第一步判断是否有WEEK_DINING_STATEMENTS视图
        String viewTopName = dmHaveDinnerRepository.judgeView("YEAR_DINING_STATEMENTS_TOP");
        if (!StringUtils.isEmpty(viewTopName)){
            //查询视图
            Page<List<Map<String, Object>>> maps = dmHaveDinnerRepository.selectYearTopView(startTime, nowTime, null);
            if (ObjectUtil.isEmpty(maps)){
                //删除视图
                dmHaveDinnerRepository.dropYearTopView("YEAR_DINING_STATEMENTS_TOP");
                //创建视图
                dmHaveDinnerRepository.createYearDiningStatementsTopThreeView(startTime,nowTime,"YEAR_DINING_STATEMENTS_TOP");
            }
        }else{
            //创建视图
            dmHaveDinnerRepository.createYearDiningStatementsTopThreeView(startTime,nowTime,"MONTH_DINING_STATEMENTS_TOP");
        }

        /**
         * 后三名
         */
        //第一步判断是否有WEEK_DINING_STATEMENTS视图
        String viewStopName = dmHaveDinnerRepository.judgeView("YEAR_DINING_STATEMENTS_STOP");
        //由于是一周一生成 那就再新增之前就要删除之前的视图
        if (!StringUtils.isEmpty(viewStopName)){
            //查询视图
            Page<List<Map<String, Object>>> maps = dmHaveDinnerRepository.selectYearStopView(startTime, nowTime, null);
            if (ObjectUtil.isEmpty(maps)){
                //删除视图
                dmHaveDinnerRepository.dropYearStopView("YEAR_DINING_STATEMENTS_STOP");
                //创建视图
                dmHaveDinnerRepository.createYearDiningStatementsStopThreeView(startTime,nowTime,"YEAR_DINING_STATEMENTS_STOP");
            }
        }else {
            //创建视图
            dmHaveDinnerRepository.createYearDiningStatementsStopThreeView(startTime,nowTime,"YEAR_DINING_STATEMENTS_STOP");
        }

    }
}
